@@ -184,9 +184,9 @@ void CalPrintPluginBase::doLoadConfig()
         mToDate = group.readEntry("ToDate", dt).date();
         mUseColors = group.readEntry("UseColors", true);
         mPrintFooter = group.readEntry("PrintFooter", true);
+        mShowNoteLines = group.readEntry("Note Lines", false);
         mExcludeConfidential = group.readEntry("Exclude confidential", true);
         mExcludePrivate = group.readEntry("Exclude private", true);
-        loadConfig();
     } else {
         qCDebug(CALENDARSUPPORT_LOG) << "No config available in loadConfig!!!!";
     }
@@ -196,7 +196,6 @@ void CalPrintPluginBase::doSaveConfig()
 {
     if (mConfig) {
         KConfigGroup group(mConfig, groupName());
-        saveConfig();
         QDateTime dt = QDateTime::currentDateTime(); // any valid QDateTime will do
         dt.setDate(mFromDate);
         group.writeEntry("FromDate", dt);
@@ -204,6 +203,7 @@ void CalPrintPluginBase::doSaveConfig()
         group.writeEntry("ToDate", dt);
         group.writeEntry("UseColors", mUseColors);
         group.writeEntry("PrintFooter", mPrintFooter);
+        group.writeEntry("Note Lines", mShowNoteLines);
         group.writeEntry("Exclude confidential", mExcludeConfidential);
         group.writeEntry("Exclude private", mExcludePrivate);
         mConfig->sync();
@@ -761,53 +761,6 @@ void CalPrintPluginBase::drawTimeLine(QPainter &p, QTime fromTime, QTime toTime,
     }
 }
 
-static QString cleanString(const QString &instr)
-{
-    QString ret = instr;
-    return ret.replace(QLatin1Char('\n'), QLatin1Char(' '));
-}
-
-void CalPrintPluginBase::drawAllDayBox(QPainter &p,
-                                      const KCalendarCore::Event::List &eventList,
-                                      QDate qd,
-                                      QRect box,
-                                      bool includeCategories,
-                                      const QList<QDate> &workDays)
-{
-    int lineSpacing = p.fontMetrics().lineSpacing();
-
-    if (!workDays.contains(qd)) {
-        drawShadedBox(p, BOX_BORDER_WIDTH, QColor(232, 232, 232), box);
-    } else {
-        drawBox(p, BOX_BORDER_WIDTH, box);
-    }
-
-    QRect eventBox(box);
-    eventBox.setTop(box.top() + padding());
-    eventBox.setBottom(eventBox.top() + lineSpacing);
-
-    for (const KCalendarCore::Event::Ptr &currEvent : std::as_const(eventList)) {
-        if (!currEvent
-            || !currEvent->allDay()
-            || (mExcludeConfidential && currEvent->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
-            || (mExcludePrivate && currEvent->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
-            continue;
-        }
-        QString str;
-        if (currEvent->location().isEmpty()) {
-            str = cleanString(currEvent->summary());
-        } else {
-            str = i18nc("summary, location", "%1, %2", cleanString(currEvent->summary()), cleanString(currEvent->location()));
-        }
-        if (includeCategories && !currEvent->categoriesStr().isEmpty()) {
-                str = i18nc("summary, categories", "%1, %2", str, currEvent->categoriesStr());
-        }
-        printEventString(p, eventBox, str);
-        eventBox.setTop(eventBox.bottom());
-        eventBox.setBottom(eventBox.top() + lineSpacing);
-    }
-}
-
 void CalPrintPluginBase::drawAgendaDayBox(QPainter &p,
                                           const KCalendarCore::Event::List &events,
                                           const QDate &qd,
@@ -1152,7 +1105,9 @@ void CalPrintPluginBase::drawDayBox(QPainter &p,
                 timeText.clear();
             }
             p.save();
-            setColorsByIncidenceCategory(p, todo);
+            if (mUseColors) {
+                setColorsByIncidenceCategory(p, todo);
+            }
             QString summaryStr = todo->summary();
             if (!todo->location().isEmpty()) {
                 summaryStr = i18nc("summary, location", "%1, %2", summaryStr, todo->location());
@@ -1292,218 +1247,6 @@ void CalPrintPluginBase::drawIncidence(QPainter &p,
     }
 }
 
-void CalPrintPluginBase::drawWeek(QPainter &p,
-                                  const QDate &qd,
-                                  const QTime &fromTime,
-                                  const QTime &toTime,
-                                  const QRect &box,
-                                  bool singleLineLimit,
-                                  bool includeDescription,
-                                  bool includeCategories)
-{
-    QDate weekDate = qd;
-    const bool portrait = (box.height() > box.width());
-    int cellWidth;
-    int vcells;
-    if (portrait) {
-        cellWidth = box.width() / 2;
-        vcells = 3;
-    } else {
-        cellWidth = box.width() / 6;
-        vcells = 1;
-    }
-    const int cellHeight = box.height() / vcells;
-
-    // correct begin of week
-    int weekdayCol = weekdayColumn(qd.dayOfWeek());
-    weekDate = qd.addDays(-weekdayCol);
-
-    for (int i = 0; i < 7; ++i, weekDate = weekDate.addDays(1)) {
-        // Saturday and sunday share a cell, so we have to special-case sunday
-        int hpos = ((i < 6) ? i : (i - 1)) / vcells;
-        int vpos = ((i < 6) ? i : (i - 1)) % vcells;
-        QRect dayBox(box.left() + cellWidth * hpos,
-                     box.top() + cellHeight * vpos + ((i == 6) ? (cellHeight / 2) : 0),
-                     cellWidth,
-                     (i < 5) ? (cellHeight) : (cellHeight / 2));
-        drawDayBox(p,
-                   weekDate,
-                   fromTime,
-                   toTime,
-                   dayBox,
-                   true,
-                   true,
-                   true,
-                   singleLineLimit,
-                   includeDescription,
-                   includeCategories);
-    } // for i through all weekdays
-}
-
-void CalPrintPluginBase::drawDays(QPainter &p,
-                                  const QDate &start,
-                                  const QDate &end,
-                                  const QTime &fromTime,
-                                  const QTime &toTime,
-                                  const QRect &box,
-                                  bool singleLineLimit,
-                                  bool includeDescription,
-                                  bool includeCategories)
-{
-    const int numberOfDays = start.daysTo(end) + 1;
-    int vcells;
-    const bool portrait = (box.height() > box.width());
-    int cellWidth;
-    if (portrait) {
-        // 2 columns
-        vcells = qCeil(static_cast<double>(numberOfDays) / 2.0);
-        if (numberOfDays > 1) {
-            cellWidth = box.width() / 2;
-        } else {
-            cellWidth = box.width();
-        }
-    } else {
-        // landscape: N columns
-        vcells = 1;
-        cellWidth = box.width() / numberOfDays;
-    }
-    const int cellHeight = box.height() / vcells;
-    QDate weekDate = start;
-    for (int i = 0; i < numberOfDays; ++i, weekDate = weekDate.addDays(1)) {
-        const int hpos = i / vcells;
-        const int vpos = i % vcells;
-        const QRect dayBox(box.left() + cellWidth * hpos, box.top() + cellHeight * vpos, cellWidth, cellHeight);
-        drawDayBox(p,
-                   weekDate,
-                   fromTime,
-                   toTime,
-                   dayBox,
-                   true,
-                   true,
-                   true,
-                   singleLineLimit,
-                   includeDescription,
-                   includeCategories);
-    } // for i through all selected days
-}
-
-void CalPrintPluginBase::drawTimeTable(QPainter &p,
-                                       const QDate &fromDate,
-                                       const QDate &toDate,
-                                       bool expandable,
-                                       const QTime &fromTime,
-                                       const QTime &toTime,
-                                       const QRect &box,
-                                       bool includeDescription,
-                                       bool includeCategories,
-                                       bool excludeTime)
-{
-    QTime myFromTime = fromTime;
-    QTime myToTime = toTime;
-    int maxAllDayEvents = 0;
-    QDate curDate(fromDate);
-    while (curDate <= toDate) {
-        KCalendarCore::Event::List eventList = mCalendar->events(curDate, QTimeZone::systemTimeZone());
-        const auto holidays = holiday(curDate);
-        int allDayEvents = holiday(curDate).isEmpty() ? 0 : 1;
-        for (const KCalendarCore::Event::Ptr &event : std::as_const(eventList)) {
-            Q_ASSERT(event);
-            if (!event
-                || (mExcludeConfidential && event->secrecy() == KCalendarCore::Incidence::SecrecyConfidential)
-                || (mExcludePrivate && event->secrecy() == KCalendarCore::Incidence::SecrecyPrivate)) {
-                continue;
-            }
-            if (event->allDay()) {
-                allDayEvents += 1;
-            } else if (expandable) {
-                if (event->dtStart().time() < myFromTime) {
-                    myFromTime = event->dtStart().time();
-                }
-                if (event->dtEnd().time() > myToTime) {
-                    myToTime = event->dtEnd().time();
-                }
-            }
-        }
-        if (allDayEvents > maxAllDayEvents) {
-            maxAllDayEvents = allDayEvents;
-        }
-        curDate = curDate.addDays(1);
-    }
-
-    QFont oldFont(p.font());
-    p.setFont(QFont(QStringLiteral("sans-serif"), 11, QFont::Normal));
-    const int lineSpacing = p.fontMetrics().lineSpacing();
-
-    int timelineWidth = TIMELINE_WIDTH + padding();
-
-    QRect dowBox(box);
-    dowBox.setLeft(box.left() + timelineWidth);
-    dowBox.setHeight(mSubHeaderHeight);
-    drawDaysOfWeek(p, fromDate, toDate, dowBox);
-
-    int tlTop = dowBox.bottom();
-
-    int alldayHeight = 0;
-    if (maxAllDayEvents > 0) {
-        // Draw the side bar for all-day events.
-        const auto alldayLabel =  i18nc("label for timetable all-day boxes", "All day");
-        QFont oldFont(p.font());
-        p.setFont(QFont(QStringLiteral("sans-serif"), 9, QFont::Normal));
-        const auto labelHeight = p.fontMetrics().horizontalAdvance(alldayLabel) + 2*padding();
-        alldayHeight = std::max(maxAllDayEvents*lineSpacing + 2*padding(), labelHeight);
-        drawVerticalBox(p,
-                        BOX_BORDER_WIDTH,
-                        QRect(0, tlTop, TIMELINE_WIDTH, alldayHeight),
-                        alldayLabel,
-                        Qt::AlignHCenter | Qt::AlignVCenter | Qt::TextWordWrap);
-        p.setFont(oldFont);
-        tlTop += alldayHeight +padding();
-    }
-
-    QRect tlBox(box);
-    tlBox.setWidth(TIMELINE_WIDTH);
-    tlBox.setTop(tlTop);
-    drawTimeLine(p, myFromTime, myToTime, tlBox);
-
-    // draw each day
-    curDate = fromDate;
-    int i = 0;
-    double cellWidth = double(dowBox.width() - 1) / double(fromDate.daysTo(toDate) + 1);
-    QRect allDayBox(dowBox.left(), dowBox.bottom(), cellWidth, alldayHeight);
-    const QList<QDate> workDays = CalendarSupport::workDays(fromDate, toDate);
-    while (curDate <= toDate) {
-        KCalendarCore::Event::List eventList =
-            mCalendar->events(curDate, QTimeZone::systemTimeZone(), KCalendarCore::EventSortStartDate, KCalendarCore::SortDirectionAscending);
-
-        allDayBox.setLeft(dowBox.left() + int(i * cellWidth));
-        allDayBox.setRight(dowBox.left() + int((i + 1) * cellWidth));
-        if (maxAllDayEvents > 0) {
-            if (const auto h = holidayEvent(curDate)) {
-                eventList.prepend(h);
-            }
-            drawAllDayBox(p, eventList, curDate, allDayBox, includeCategories, workDays);
-        }
-
-        QRect dayBox(allDayBox);
-        dayBox.setTop(tlTop);
-        dayBox.setBottom(box.bottom());
-        drawAgendaDayBox(p,
-                         eventList,
-                         curDate,
-                         false,
-                         myFromTime,
-                         myToTime,
-                         dayBox,
-                         includeDescription,
-                         includeCategories,
-                         excludeTime,
-                         workDays);
-
-        ++i;
-        curDate = curDate.addDays(1);
-    }
-}
-
 class MonthEventStruct
 {
 public:
